shopt -s extglob

bundleType=dmg

i=0
while ((i++<$#)); do
    arg="${@:i:1}"
    val="${@:i+1:1}"
    case "$arg" in
        -B) useReleaseBuild=1 ;;
        -t) bundleType="$val"; ((i++)) ;;
         *) echo >&2 "Unknown option to $BASH_SOURCE: $arg" ;;
    esac
done 


jbin=$(/usr/libexec/java_home)/bin
# This file is inside RNAstructure/RELEASE/scripts directory
cd "${BASH_SOURCE[0]%/*}"/..  # Now CWD is RNAstructure/RELEASE/  (this is important because package/ needs to be in the classpath of javapackager. The easiest way to do that is to have it in . (PWD)
source release.cfg  # includes $VERSION, $RELEASE_DATE, $BUNDLE_JDK
source scripts/releaseUtils.bash  # contains replaceVars
#echo DIR=$(pwd)

src=deploy-src
dst=deploy

function cpdir() { rsync -au "$@"; }
function cpf() { cp -fp "$@"; }

ospkg=package/macosx
res=resources

rm -rf $src $dst
mkdir -p $src

if [[ $useReleaseBuild ]]; then
    # CWD is RNAstructure/RELEASE/
    # The release build folder is one level above RNAstructure
    build=../../BUILD_v$VERSION
    rna_exe=$build/macGUI/RNAstructure/exe
    rna_src=$build/mac64/RNAstructure
else
    # CWD is RNAstructure/RELEASE/
    rna_src=..
    rna_exe=../exe
fi

cpf $rna_exe/RNAstructure.jar  $rna_exe/?(lib)RNAstructure*.?(so|dll|dylib)  $src
cpf $rna_src/java_interface/ui-resources/images/logo.png  $src

cpdir $rna_src/examples $src
cpdir $rna_src/manual/GUI/ $src/manual
cpdir $rna_src/data_tables $src

#replaceVars  <$res/Info.plist.tpl  >$ospkg/Info.plist

#cp resources/*icns $src
src_files=$(for f in $src/*; do printf "%q:" "${f##*/}"; done )

# Set up arguments
packagerArgs=(
    # Qualified name of the application class to be executed.
    -appclass ur_rna.RNAstructureUI.RNAstructure
   
    # Description of the application.
    -description 'RNA and DNA secondary structure prediction application.'

    # Name of the application.
    -name RNAstructure
    
    # Name of the directory that will receive generated output files.
    -outdir $dst
    -outfile RNAstructure           # -- Name (without the extension) of the file that will be generated.

    #  Base directory of the files to package.
    -srcdir $src
    -srcfiles "$src_files"

    # -srcfiles files             # -- List of files in the directory specified by the -srcdir option. If omitted, all files in the directory (which is a mandatory argument in this case) will be used. Files in the list must be separated by spaces.
    # -allpermissions             # -- If present, the application will require all security permissions in the JNLP file.
    # -argument arg               # -- An unnamed argument to be inserted into an <fx:argument> element in the JNLP file.
    # -callbacks                  # -- Specifies user callback methods in generated HTML. The format is the following: "name1:value1,name2:value2,..."
    # -embedCertificates          # -- If present, the certificates will be embedded in the JNLP file.
    # -embedjnlp                  # -- If present, the JNLP file will be embedded in the HTML document.
    # -height height              # -- Height of the application.     
    # -htmlparamfile file         # -- Properties file with parameters for the resulting application when it is run in the browser.
    # -isExtension                # -- If present, the srcfiles are treated as extensions.
    # -nosign                     # -- If present, the bundle generated for self-contained applications is not signed by the bundler. The default for bundlers that support signing is to sign the bundle if signing keys are properly configured. This attribute is ignored by bundlers that do not support signing. At the time of the 8u40 release of the JDK, only OS X bundlers support signing.
    # -paramfile file             # -- Properties file with default named application parameters.
    # -preloader preloader-class  # -- Qualified name of the JavaFX preloader class to be executed. Use this option only for JavaFX applications. Do not use for Java applications, including headless applications.
    # -templateId                 # -- Application ID of the application for template processing.
    # -templateInFilename         # -- Name of the HTML template file. Placeholders are in the following form:  #XXXX.YYYY(APPID)#  (Where APPID is the identifier of an application and XXX is one of those on  http://docs.oracle.com/javase/8/docs/technotes/tools/unix/javapackager.html#BGBIJBHF for details)
    # -templateOutFilename        # -- Name of the HTML file that will be generated from the template.
    # -title title                # -- Title of the application.
    # -vendor vendor              # -- Vendor of the application.
    # -width width                # -- Width of the application.
    # -updatemode update-mode     # -- Sets the update mode for the JNLP file.


    # Generate self-contained application bundles (if possible). Use the -B option to provide arguments to the bundlers being used. If type is specified, then only a bundle of this type is created. If no type is specified, all is used.
    #   The following values are valid for type:
    #   all: Runs all of the installers for the platform on which it is running, and creates a disk image for the application. This value is used if type is not specified.
    #   installer: Runs all of the installers for the platform on which it is running.
    #   image: Creates a disk image for the application. On OS X, the image is the .app file. On Linux, the image is the directory that gets installed.
    #   dmg: Generates a DMG file for OS X.
    #   pkg: Generates a .pkg package for OS X.
    #   mac.appStore: Generates a package for the Mac App Store.
    #   rpm: Generates an RPM package for Linux.
    #   deb: Generates a Debian package for Linux.
    -native $bundleType  # Note: It appears that 'all' doesn't actually work.

    # Provides information to the bundler that is used to package a self-contained application. See Arguments for Self-Contained Application Bundlers for information on the arguments for each bundler.
    # (These are used below.)
    # -Bbundler-argument=value 
    
    #### General Bundler Arguments ####
    # -BappVersion=version            # -- Version of the application package. Some bundlers restrict the format of the version string.
    -BappVersion=$VERSION
    # -BclassPath=path                # -- Class path relative to the assembled application directory. The path is typically extracted from the JAR file manifest, and does not need to be set if you are using the other javapackager commands.
    # -Bicon=path                     # -- Location of the default icon to be used for launchers and other assists. For OS X, the format must be .icns. For Linux, the format must be .png.
    -Bicon=RNAstructure.icns
    # -Bidentifier=value              # -- Default value that is used for other platform-specific values such as mac.CFBundleIdentifier. Reverse DNS order is recommended, for example, com.example.application.my-application.
    -Bidentifier=ur_rna.RNAstructureJavaGUI
    # -BjvmOptions=option             # -- Option to be passed to the JVM when the application is run. Any option that is valid for the java command can be used. 
    #                                 #    To pass more than one option, use multiple instances of the -B option, as shown in the following example: -BjvmOptions=-Xmx128m -BjvmOptions=-Xms128m
    -BjvmOptions=-splash:logo.png

    # -BjvmProperties=property=value  # -- Java System Property to be passed to the VM when the application is run. Any property that is valid for the -D option of the java command can be used. Specify both the property name and the value for the property. 
    #                                 #    To pass more than one property, use multiple instances of the -B option, as shown in the following example:   -BjvmProperties=apiUserName=example  -BjvmProperties=apiKey=abcdef1234567890
    # -BmainJar=filename              # -- Name of the JAR file that contains the main class for the application. The file name is typically extracted from the JAR file manifest, and does not need to be set if you are using the other javapackager commands.
    -BmainJar=RNAstructure.jar
    # -BpreferencesID=node            # -- Preferences node to examine to check for JVM options that the user can override. The node specified is passed to the application at run time as the option -Dapp.preferences.id. This argument is used with the userJVMOptions argument.
    # -Bruntime=path                  # -- Location of the JRE or JDK to include in the package bundle. Provide a file path to the root folder of the JDK or JRE. 
    #-Bruntime=$BUNDLE_JDK
    #                                 #    To use the system default JRE, do not provide a path, as shown in the following example: -Bruntime=
    # -BuserJvmOptions=option=value   # -- JVM options that users can override. Any option that is valid for the java command can be used. Specify both the option name and the value for the option. 
    #                                 #    To pass more than one option, use multiple instances of the -B option, as shown in the following example:  -BuserJvmOptions=-Xmx=128m -BuserJvmOptions=-Xms=128m
    
    #### OS X Application Bundler Arguments ####
    # -Bmac.category=category                 # -- Category for the application. The category must be in the list of categories found on the Apple Developer website.
    -Bmac.category=public.app-category.education
    # -Bmac.CFBundleIdentifier=value          # -- Value stored in the info plist for CFBundleIdentifier. This value must be globally unique and contain only letters, numbers, dots, and dashes. Reverse DNS order is recommended, for example, com.example.application.my-application.
    -Bmac.CFBundleIdentifier=ur_rna.RNAstructureJavaGUI
    # -Bmac.CFBundleName=name                 # -- Name of the application as it appears on the OS X Menu Bar. A name of less than 16 characters is recommended. The default is the name attribute.
    -Bmac.CFBundleName=RNAstructure
    # -Bmac.CFBundleVersion=value             # -- Version number for the application, used internally. The value must be at least one integer and no more than three integers separated by periods (.) for example, 1.3 or 2.0.1. The value can be different than the value for the appVersion argument. If the appVersion argument is specified with a valid value and the mac.CFBundleVersion argument is not specified, then the appVersion value is used. If neither argument is specified, 100 is used as the version number.
    # -Bmac.signing-key-developer-id-app=key  # -- Name of the signing key used for Devleloper ID or Gatekeeper signing. If you imported a standard key from the Apple Developer Website, then that key is used by default. If no key can be identified, then the application is not signed.
    # -Bmac.bundle-id-signing-prefix=prefix   # -- Prefix that is applied to the signed binary when binaries that lack plists or existing signatures are found inside the bundles.
    
    #### OS X DMG (Disk Image) Bundler Arguments ####  The OS X DMG installer shows the license file specified by licenseFile, if provided, before allowing the disk image to be mounted.
    # -BlicenseFile=path           # -- Location of the End User License Agreement (EULA) to be presented or recorded by the bundler. The path is relative to the packaged application resources, for example, -BlicenseFile=COPYING.
    # -BsystemWide=boolean         # -- Flag that indicates which drag-to-install target to use. Set to true to show the Applications folder. Set to false to show the Desktop folder. The default is true.
    # -Bmac.CFBundleVersion=value  # -- Version number for the application, used internally. The value must be at least one integer and no more than three integers separated by periods (.) for example, 1.3 or 2.0.1. The value can be different than the value for the appVersion argument. If the appVersion argument is specified with a valid value and the mac.CFBundleVersion argument is not specified, then the appVersion value is used. If neither argument is specified, 100 is used as the version number.
    # -Bmac.dmg.simple=boolean     # -- Flag that indicates if DMG customization steps that depend on executing AppleScript code are skipped. Set to true to skip the steps. When set to true, the disk window does not have a background image, and the icons are not moved into place. If the systemWide argument is also set to true, then a symbolic link to the root Applications folder is added to the DMG file. If the systemWide argument is set to false, then only the application is added to the DMG file, no link to the desktop is added.
    
    #### OS X PKG Bundler Arguments ####  The OS X PKG installer presents a wizard and shows the license file specified by licenseFile as one of the pages in the wizard. The user must accept the terms before installing the application.
    # -BlicenseFile=path                            # -- Location of the End User License Agreement (EULA) to be presented or recorded by the bundler. The path is relative to the packaged application resources, for example, -BlicenseFile=COPYING.
    # -Bmac.signing-key-developer-id-installer=key  # -- Name of the signing key used for Developer ID or Gatekeeper signing. If you imported a standard key from the Apple Developer Website, then that key is used by default. If no key can be identified, then the application is not signed.
     -Bmac.CFBundleVersion=$VERSION                   # -- Version number for the application, used internally. The value must be at least one integer and no more than three integers separated by periods (.) for example, 1.3 or 2.0.1. The value can be different than the value for the appVersion argument. If the appVersion argument is specified with a valid value and the mac.CFBundleVersion argument is not specified, then the appVersion value is used. If neither argument is specified, 100 is used as the version number.
    
    #### Mac App Store Bundler Arguments ####
    # -Bmac.app-store-entitlements=path  # -- Location of the file that contains the entitlements that the application operates under. The file must be in the format specified by Apple. The path to the file can be specified in absolute terms, or relative to the invocation of javapackager. If no entitlements are specified, then the application operates in a sandbox that is stricter than the typical applet sandbox, and access to network sockets and all files is prevented.
    # -Bmac.signing-key-app=key          # -- Name of the application signing key for the Mac App Store. If you imported a standard key from the Apple Developer Website, then that key is used by default. If no key can be identified, then the application is not signed.
    # -Bmac.signing-key-pkg=key          # -- Name of the installer signing key for the Mac App Store. If you imported a standard key from the Apple Developer Website, then that key is used by default. If no key can be identified, then the application is not signed.
    # -Bmac.CFBundleVersion=value        # -- Version number for the application, used internally. The value must be at least one integer and no more than three integers separated by periods (.) for example, 1.3 or 2.0.1. The value can be different than the value for the appVersion argument. If the appVersion argument is specified with a valid value and the mac.CFBundleVersion argument is not specified, then the appVersion value is used. If neither argument is specified, 100 is used as the version number. If this version is an upgrade for an existing application, the value must be greater than previous version number.
    
    #### Linux Debian Bundler Arguments #### The license file specified by licenseFile is not presented to the user in all cases, but the file is included in the application metadata.
    # -Bcategory=category  # -- Category for the application. See http://standards.freedesktop.org/menu-spec/latest/apa.html for examples.
    -Bcategory=Science
    # -Bcopyright=string   # -- Copyright string for the application. This argument is used in the Debian metadata.
    # -Bemail=address      # -- Email address used in the Debian Maintainer field.
    # -BlicenseFile=path   # -- Location of the End User License Agreement (EULA) to be presented or recorded by the bundler. The path is relative to the packaged application resources, for example, -BlicenseFile=COPYING.
    # -BlicenseType=type   # -- Short name of the license type, such as -BlicenseType=Proprietary, or "-BlicenseType=GPL v2 + Classpath Exception".
    # -Bvendor=value       # -- Corporation, organization, or individual providing the application. This argument is used in the Debian Maintainer field.
    
    #### Linux RPM Bundler Arguments ####
    # -Bcategory=category  # -- Category for the application. See http://standards.freedesktop.org/menu-spec/latest/apa.html for examples.
    # -BlicenseFile=path   # -- Location of the End User License Agreement (EULA) to be presented or recorded by the bundler. The path is relative to the packaged application resources, for example, -BlicenseFile=COPYING.
    # -BlicenseType=type   # -- Short name of the license type, such as -BlicenseType=Proprietary, or "-BlicenseType=GPL v2 + Classpath Exception".
    # -Bvendor=value       # -- Corporation, organization, or individual providing the application.
)

printf "%s\n" "${packagerArgs[@]}" > $src/javapackager_args.log
$jbin/javapackager  -deploy "${packagerArgs[@]}" -v

# $jpkg -deploy -appclass ur_rna.RNAstructureUI.RNAstructure -name RNAstructure \
#     -outdir ./deploy  -outfile RNAstructure_Mac -srcdir $rnas/exe \
#     -srcfiles 'RNAstructure.jar:libRNAstructure_GUI.dylib' \
#     -native pkg \
#     -BappVersion=5.9 -Bicon=RNAstructure.icns -Bidentifier=ur_rna.RNAstructureJavaGUI \
#     -BmainJar=RNAstructure.jar \

