package ur_rna.Utilities;

/**
 * Created by Richard on 4/12/2016.
 */
public class StopWatch {
    // Stores the time at which the StopWatch was started.
    // If the watch is stopped, it stores the elapsed time as a negative number.
    // When restarted, the time (as a negative number) is added to the CURRENT time so that the total elapsed will be correct.
    // So:
    //    (time == 0) --  Not yet started. Elapsed time is 0.
    //    (time > 0)  --  Already started and currently running. Elapsed time is `getTime() - time`
    //    (time < 0)  --  Started previously, but currently stopped. Elapsed time is `-time`
    private long time;
    /**
     * Start the timer. If it is already running, this has no effect.
     */
    public void start() {
        if (time == 0)
            time = getTime();
        else if (time < 0)
            time = time + System.currentTimeMillis();
        // otherwise it is already started.
    }
    /**
     * Stop the timer, but store the elapsed time so that when {@link #start()} is called,
     * the elapsed time will continue to increase.
     * If the timer is already stopped, this has no effect.
     */
    public void stop() {
        if (time > 0)
            time = time - System.currentTimeMillis(); // get amount of time run, but store it as negative to indicate that it is a duration.
    }
    /**
     * The total elapsed time in milliseconds.
     */
    public long elapsed() {
        if (time == 0) return 0;
        return (time < 0 ? 0 : getTime()) - time;
    }
    /**
     * Reset elapsed time to 0 and stop the timer.
     */
    public void reset() {
        time = 0;
    }
    /**
     * Reset elapsed time to 0 and start the timer.
     */
    public void restart() {
        time = getTime();
    }
    public boolean isStarted() { return time > 0; }

    public static long getTime() {
        return System.currentTimeMillis();
    }
    public void printElapsed(String message) {
        System.out.printf("@\t%s\t%s"+System.lineSeparator(), message, elapsed());
    }
}
